#!/usr/bin/env python
# -*- coding:utf-8 -*-

#############################################
# File Name: 图片.py
# Mail: 1957875073@qq.com
# Created Time:  2022-4-25 10:17:34
# Description: 有关 图片 的自动化操作
#############################################
from office.core.ImageType import MainImage

mainImage = MainImage()


def image2gif():
    mainImage.image2gif()


def add_watermark(file, mark, out="output", color="#8B8B1B", size=30, opacity=0.15, space=75, angle=30):
    mainImage.add_watermark(file, mark, out, color, size, opacity, space, angle)


def img2Cartoon(path):
    mainImage.img2Cartoon(path)



from office.core.ToolsType import MainTools

mainTools = MainTools()


def transtools(to_lang, content):
    mainTools.transtools(to_lang, content)


def qrcodetools(url):
    mainTools.qrcodetools(url)


def passwordtools(len=8):
    mainTools.passwordtools(len)


def weather():
    mainTools.weather()


# 通过url，获取ip地址
def url2ip(url):
    mainTools.url2ip(url)



from faker import Faker
import pandas as pd
from alive_progress import alive_bar
from office.lib.utils import pandas_mem


class MainExcel():

    def fake2excel(self, columns, rows, language, path):
        """
        @Author & Date  : CoderWanFeng 2022/5/13 0:12
        @Desc  : columns:list，每列的数据名称，默认是名称
                rows：多少行，默认是1
                language：什么语言，可以填english，默认是中文
                path：输出excel的位置，有默认值
        """
        # 可以选择英语
        if language.lower() == 'english':
            language = 'en_US'
        # 开始造数
        fake = Faker(language)
        excel_dict = {}
        with alive_bar(len(columns) * rows) as bar:
            for column in columns:
                excel_dict[column] = list()
                # excel_dict[column] = map(lambda x: eval('fake.{func}()'.format(func=x)), [column] * rows) # 使用map，会报错
                while len(excel_dict[column]) < rows:
                    excel_dict[column].append(eval('fake.{func}()'.format(func=column)))
                    bar()
            # 用pandas，将模拟数据，写进excel里面
            writer = pd.ExcelWriter(path)
            data = pd.DataFrame(excel_dict)
            data = pandas_mem.reduce_pandas_mem_usage(data)
            data.to_excel(writer, index=False)
            writer.save()



# -*- coding: utf-8 -*-

from office.core.PDFType import MainPDF

mainPDF = MainPDF()


# 给pdf加水印
def add_watermark():
    mainPDF.add_watermark()


# txt转pdf
def txt2pdf(path, res_pdf='txt2pdf.pdf'):
    mainPDF.file2pdf(path, res_pdf)


# PDF加密
def encrypt4pdf(path, password, res_pdf='encrypt.pdf'):
    mainPDF.encrypt4pdf(path, password, res_pdf)


# PDF解密
def decrypt4pdf(path, password, res_pdf='decrypt.pdf'):
    mainPDF.decrypt4pdf(path, password, res_pdf)


# 合并pdf
def merge2pdf(one_by_one, output):
    mainPDF.merge2pdf(one_by_one, output)


def pdf2docx(file_path):
    mainPDF.pdf2docx(file_path)



#!/usr/bin/env python
# -*- coding:utf-8 -*-

#############################################
# File Name: excel.py
# Mail: 1957875073@qq.com
# Created Time:  2022-4-25 10:17:34
# Description: 有关 excel 的自动化操作
#############################################
from office.core.ExcelType import MainExcel

mainExcel = MainExcel()


def fake2excel(columns=['name'], rows=1, language='zh_CN', path='./fake2excel.xlsx'):
    mainExcel.fake2excel(columns, rows, language, path)
